parse

Function parse 

pub fn parse(data: &[u8]) -> Option<ApplePartitionMap>
Parse an Apple Partition Map from a buffer beginning at the device start (block 0 = Driver Descriptor Map). Returns None without the ER/PM signatures or if the buffer is too short.